==> qtsmbstatus_2.0.3.orig.tar.gz: qtsmbstatus-2.0.3/client/login_windows.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Daniel Rocher                                   *
 *   daniel.rocher@adella.org                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#ifndef LOGIN_WINDOWS_H
#define LOGIN_WINDOWS_H


#include "ui_login_dialog.h"

extern void debugQt(const QString & message);
extern QString username_login;
extern QString passwd_login;

class login_windows :public QDialog, public Ui::login_dialog
{
Q_OBJECT
public:
    login_windows(QWidget *parent = 0);
    virtual ~login_windows();
private slots:
	virtual void Slot_login_button();
};

#endif

==> qtsmbstatus_2.2.1.orig.tar.gz: qtsmbstatus-2.2.1/client/login_windows.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Daniel Rocher                                   *
 *   daniel.rocher@adella.org                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#ifndef LOGIN_WINDOWS_H
#define LOGIN_WINDOWS_H


#include "build/ui/ui_login_dialog.h"

extern void debugQt(const QString & message);
extern QString username_login;
extern QString passwd_login;

class login_windows :public QDialog, public Ui::login_dialog
{
   Q_OBJECT
public:
    login_windows(QWidget *parent = 0);
    virtual ~login_windows();
private slots:
	void on_bt_login_clicked();
};

#endif
